Error types for the fin-primitives crate.
All errors are named, typed, and propagatable via thiserror.
Every variant has at least one test that triggers it.
Enums
- FinError
- All errors that can occur in fin-primitives operations.